@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2023-2024 -- leonerd@leonerd.org.uk
 
-package Object::Pad::FieldAttr::Checked 0.11;
+package Object::Pad::FieldAttr::Checked 0.12;
 
 use v5.14;
 use warnings;
@@ -82,12 +82,6 @@ An B<object> reference with a C<check> method:
 
 =item *
 
-A B<code> reference:
-
-   $ok = $checkersub->( $value );
-
-=item *
-
 A B<plain string> giving the name of a package with a C<check> method:
 
    $ok = $checkerpkg->check( $value );
